@@ -12,15 +12,18 @@ import numpy
 import math
 
 # import external modules written for MicroscopeAutomation
-from ..preferences import Preferences
-from .. import automation_messages_form_layout as message
-from ..get_path import get_hardware_settings_path, get_colony_file_path
-from . import samples
+from microscope_automation.settings.preferences import Preferences
+from microscope_automation.util import automation_messages_form_layout as message
+from microscope_automation.util.get_path import (
+    get_hardware_settings_path,
+    get_colony_file_path,
+)
+from microscope_automation.samples import samples
 
 # create logger
 import logging
 
-logger = logging.getLogger("microscope_automation")
+logger = logging.getLogger(__name__.split(".")[0])
 
 
 ###########################################################################
@@ -42,9 +45,7 @@ def get_colony_data(prefs, colony_file):
      colonies: pandas frame with content of .csv file
     """
     # setup logging
-    logger = logging.getLogger(  # noqa
-        "microscope_automation.samples.setup_samples.get_colony_data"
-    )
+    logger = logging.getLogger(__name__)  # noqa
 
     ##############################
     # this portion will be replaces by calls to LIMS system
@@ -69,6 +70,7 @@ def get_colony_data(prefs, colony_file):
             ),
         )
     ]
+    selected_plate_id_list = [int(i) for i in selected_plate_id_list]
     plate_selector = colonies_all.loc[:, "PlateID"].isin(selected_plate_id_list)
 
     # select columns as defined in preferences.yml file
